@@ -9,15 +9,18 @@ import universe_tables
 import util
 
 
-class AdjacencyGrid(object):
+class AdjacencyGrid:
     def __init__(self, universe_width):
+        """
+        :param float universe_width:
+        """
         assert universe_tables.MIN_SYSTEM_SEPARATION < universe_tables.MAX_STARLANE_LENGTH
         self.min_dist = universe_tables.MIN_SYSTEM_SEPARATION
         self.max_dist = universe_tables.MAX_STARLANE_LENGTH
         self.cell_size = min(max(universe_width / 50, self.min_dist), self.max_dist / sqrt(2))
         self.width = int(universe_width / self.cell_size) + 1
         self.grid = defaultdict(set)
-        print "Adjacency Grid: width {}, cell size {}".format(self.width, self.cell_size)
+        print("Adjacency Grid: width {}, cell size {}".format(self.width, self.cell_size))
 
     def cell(self, pos):
         """Returns cell index."""
@@ -31,8 +34,9 @@ class AdjacencyGrid(object):
         """Removes pos."""
         self.grid[self.cell(pos)].discard(pos)
 
-    def _square_indices_containing_cell(self, (cell_x, cell_y), radius):
+    def _square_indices_containing_cell(self, cell, radius):
         """Return a square of indices containing cell."""
+        cell_x, cell_y = cell
         upper_left_x = max(0, cell_x - radius)
         upper_left_y = max(0, cell_y - radius)
         lower_right_x = min(self.width - 1, cell_x + radius)
@@ -85,7 +89,7 @@ class AdjacencyGrid(object):
                    for p2 in self.grid[p2_cell])
 
 
-class DSet(object):
+class DSet:
     """
     A set of pos that is disjoint (not connected) to other sets.
 
@@ -114,7 +118,7 @@ class DSet(object):
         self.rank += 1
 
 
-class DisjointSets(object):
+class DisjointSets:
     """
     A set of disjoint sets.
 
@@ -202,10 +206,10 @@ class DisjointSets(object):
         ret = defaultdict(list)
         for pos in self.dsets.keys():
             ret[self.root(pos)].append(pos)
-        return ret.values()
+        return list(ret.values())
 
 
-class Clusterer(object):
+class Clusterer:
     """
     Computes all clusters of positions separated by more than MAX_STARLANE_LENGTH
 
@@ -333,7 +337,7 @@ def enforce_max_distance(positions, adjacency_grid):
     clusterer = Clusterer(positions, adjacency_grid)
 
     if len(clusterer) == 1:
-        print "All systems positioned in a single connected cluster"
+        print("All systems positioned in a single connected cluster")
     else:
         print("{} clusters separated by more than the MAX_STARLANE_LENGTH."
               "  Starting to fill gaps.".format(len(clusterer)))
@@ -362,7 +366,7 @@ def enforce_max_distance(positions, adjacency_grid):
         clusterer.stitch_clusters(p1, p2, extra_positions)
 
         if len(clusterer) == 1:
-            print "All systems now positioned in a single connected cluster"
+            print("All systems now positioned in a single connected cluster")
         else:
             print("{} clusters separated by more the MAX_STARLANE_LENGTH.  "
                   "Continuing to fill gaps.".format(len(clusterer)))
@@ -518,9 +522,13 @@ def disc_galaxy_calc_positions(positions, adjacency_grid, size, width):
 def cluster_galaxy_calc_positions(positions, adjacency_grid, size, width):
     """
     Calculate positions for the cluster galaxy shape.
+    :type positions: list
+    :type adjacency_grid: AdjacencyGrid
+    :type size: int
+    :type width: float
     """
     if size < 1:
-        print >> sys.stderr, "Cluster galaxy requested for less than 1 star"
+        print("Cluster galaxy requested for less than 1 star", file=sys.stderr)
         return
 
     if size == 1:
@@ -638,6 +646,8 @@ def ring_galaxy_calc_positions(positions, adjacency_grid, size, width):
 def box_galaxy_calc_positions(positions, adjacency_grid, size, width):
     """
     Calculate positions for the box galaxy shape.
+
+    :param float width:
     """
     for i in range(size):
         attempts = 100
@@ -670,7 +680,7 @@ def irregular_galaxy_calc_positions(positions, adjacency_grid, size, width):
     Calculate positions for the irregular galaxy shape.
     """
     max_delta = max(min(float(universe_tables.MAX_STARLANE_LENGTH), width / 10.0), adjacency_grid.min_dist * 2.0)
-    print "Irregular galaxy shape: max delta distance = {}".format(max_delta)
+    print("Irregular galaxy shape: max delta distance = {}".format(max_delta))
     origin_x, origin_y = width / 2.0, width / 2.0
     prev_x, prev_y = origin_x, origin_y
     reset_to_origin = 0
@@ -693,7 +703,7 @@ def irregular_galaxy_calc_positions(positions, adjacency_grid, size, width):
             adjacency_grid.insert_pos(pos)
             positions.append(pos)
         prev_x, prev_y = x, y
-    print "Reset to origin {} times".format(reset_to_origin)
+    print("Reset to origin {} times".format(reset_to_origin))
 
 
 def recalc_universe_width(positions):
@@ -704,7 +714,7 @@ def recalc_universe_width(positions):
 
     Returns the new universe width and the recalculated positions.
     """
-    print "Recalculating universe width..."
+    print("Recalculating universe width...")
     # first, get the uppermost, lowermost, leftmost and rightmost positions
     # (these are those with their x or y coordinate closest to or farthest away from the x or y axis)
     min_x = min(positions, key=lambda p: p[0])[0]
@@ -726,13 +736,13 @@ def recalc_universe_width(positions):
     width = max_x - min_x
     height = max_y - min_y
     actual_width = max(width, height) + 20.0
-    print "...recalculated universe width: {}".format(actual_width)
+    print("...recalculated universe width: {}".format(actual_width))
 
     # shift all positions so the entire map is centered in a quadratic box of the width we just calculated
     # this box defines the extends of our universe
     delta_x = ((actual_width - width) / 2) - min_x
     delta_y = ((actual_width - height) / 2) - min_y
-    print "...shifting all system positions by {}/{}".format(delta_x, delta_y)
+    print("...shifting all system positions by {}/{}".format(delta_x, delta_y))
     new_positions = [(p[0] + delta_x, p[1] + delta_y) for p in positions]
 
     print("...the leftmost system position is now at x coordinate {}"
@@ -756,13 +766,13 @@ def calc_star_system_positions(gsd):
 
     # calculate typical width for universe based on number of systems
     width = calc_universe_width(gsd.shape, gsd.size)
-    print "Set universe width to {}".format(width)
+    print("Set universe width to {}".format(width))
     fo.set_universe_width(width)
 
     positions = []
     adjacency_grid = AdjacencyGrid(width)
 
-    print "Creating {} galaxy shape".format(gsd.shape)
+    print("Creating {} galaxy shape".format(gsd.shape))
     if gsd.shape == fo.galaxyShape.spiral2:
         spiral_galaxy_calc_positions(positions, adjacency_grid, 2, gsd.size, width)
     elif gsd.shape == fo.galaxyShape.spiral3:
@@ -790,7 +800,7 @@ def calc_star_system_positions(gsd):
     # to avoid having too much "extra space" around the system positions of our galaxy map, recalculate the universe
     # width and shift all positions accordingly
     width, positions = recalc_universe_width(positions)
-    print "Set universe width to {}".format(width)
+    print("Set universe width to {}".format(width))
     fo.set_universe_width(width)
 
     return positions
